@@ -18,7 +18,9 @@ class IDDict(dict):
             return key + "=" + str(self[key])
 
         _id_dict = {k: self[k] for k in id_keys}
-        return hashlib.md5(json.dumps(_id_dict, sort_keys=True).encode('utf-8')).hexdigest()
+        return hashlib.md5(
+            json.dumps(_id_dict, sort_keys=True).encode("utf-8")
+        ).hexdigest()
 
 
 class BatchKwargs(IDDict):
